bling
=====

.. image:: https://img.shields.io/pypi/v/bling.svg
    :target: https://pypi.python.org/pypi/bling
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/ungood/bling.svg?branch=master
    :target: https://travis-ci.org/ungood/bling  
    :alt: Latest Travis CI build status

Bling is a simple language for controlling LED strips.

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`bling` was written by `Jason Walker <ungood@onetrue.name>`_.
